DatasetGraph

Struct DatasetGraph 

pub struct DatasetGraph<D, G>
where D: Dataset, G: Term,
{ /* private fields */ }
I wrap a Dataset as a Graph corresponding to a specific graph (default or named) of the wrapped dataset.

This graph is also mutable if the underlying dataset is.

NB: this type is design to be the return type of Dataset::graph and MutableDataset::graph_mut. It is not designed to be usable “from scratch”.

Implementations

Source

impl<D, G> DatasetGraph<D, G>
where D: Dataset, G: Term,

pub fn new(d: D, g: Option<G>) -> DatasetGraph<D, G>

Wrap the given dataset as a single Graph (selected via the given graph name).

pub fn unwrap(self) -> (D, Option<G>)

Unwrap the inner GraphName and Dataset.