pub type GTermSource<'a, G> = Box<dyn Iterator<Item = Result<<<G as Graph>::Triple<'a> as Triple>::Term, <G as Graph>::Error>> + 'a>;๐Deprecated since 0.8.1:
prototypes of term-yielding methods have changed
Type alias for fallible term iterators produced by a graph.
See Graph::subjects for more information about how to use it.
Aliased Type
pub struct GTermSource<'a, G>(/* private fields */);