pub struct Any;Trait Implementations
Sourceimpl GraphNameMatcher for Any
impl GraphNameMatcher for Any
Sourcetype Term = SimpleTerm<'static>
type Term = SimpleTerm<'static>
The type of term that this GraphNameMatcher contains
Sourcefn constant(&self) -> Option<Option<&Self::Term>>
fn constant(&self) -> Option<Option<&Self::Term>>
Return
None, unless this matcher can only match a single graph name,
in which case this method may return that graph name. Read moreSourcefn matcher_ref(&self) -> MatcherRef<'_, Self>
fn matcher_ref(&self) -> MatcherRef<'_, Self>
Return a
GraphNameMatcher that is actually just a reference to this one.Sourceimpl<T> Mul<LanguageTag<T>> for Any
impl<T> Mul<LanguageTag<T>> for Any
Sourcetype Output = LanguageTagMatcher<T>
type Output = LanguageTagMatcher<T>
The resulting type after applying the
* operator.Sourcefn mul(self, rhs: LanguageTag<T>) -> <Any as Mul<LanguageTag<T>>>::Output
fn mul(self, rhs: LanguageTag<T>) -> <Any as Mul<LanguageTag<T>>>::Output
Performs the
* operation. Read moreSourceimpl TermMatcher for Any
impl TermMatcher for Any
Sourcetype Term = SimpleTerm<'static>
type Term = SimpleTerm<'static>
The type of term that this TermMatcher contains
Sourcefn constant(&self) -> Option<&Self::Term>
fn constant(&self) -> Option<&Self::Term>
Return
None, unless this matcher can only match a single term,
in which case this method may return that term. Read moreSourcefn gn(self) -> TermMatcherGn<Self>where
Self: Sized,
fn gn(self) -> TermMatcherGn<Self>where
Self: Sized,
Sourcefn matcher_ref(&self) -> MatcherRef<'_, Self>
fn matcher_ref(&self) -> MatcherRef<'_, Self>
Return a
TermMatcher that is actually just a reference to this one.impl Copy for Any