SimpleTerm

Enum SimpleTerm 

pub enum SimpleTerm<'a> {
    Iri(IriRef<MownStr<'a>>),
    BlankNode(BnodeId<MownStr<'a>>),
    LiteralDatatype(MownStr<'a>, IriRef<MownStr<'a>>),
    LiteralLanguage(MownStr<'a>, LanguageTag<MownStr<'a>>, Option<BaseDirection>),
    Triple(Box<[SimpleTerm<'a>; 3]>),
    Variable(VarName<MownStr<'a>>),
}
A straightforward implementation of Term as an enum.

Variants



Iri(IriRef<MownStr<'a>>)



BlankNode(BnodeId<MownStr<'a>>)

An RDF blank node



LiteralDatatype(MownStr<'a>, IriRef<MownStr<'a>>)

An RDF literal



LiteralLanguage(MownStr<'a>, LanguageTag<MownStr<'a>>, Option<BaseDirection>)

An RDF language-tagged string, potentially with base direction



Triple(Box<[SimpleTerm<'a>; 3]>)

An RDF triple term



Variable(VarName<MownStr<'a>>)

A SPARQL or Notation3 variable

Implementations

Source

impl<'a> SimpleTerm<'a>

pub fn from_term_ref<T>(term: &'a T) -> SimpleTerm<'a>
where T: Term + ?Sized,

Build a SimpleTerm that borrows as much as possible from the original term.

NB: depending on the implementation of term, some data might still be allocated.

pub fn from_triple<T>(triple: T) -> SimpleTerm<'a>
where T: Triple,

Build a SimpleTerm of kind Triple from any triple.