LanguageTagMatcher

Struct LanguageTagMatcher 

pub struct LanguageTagMatcher<T>(/* private fields */)
where
    T: Borrow<str>;
A TermMatcher that matches all literals with a given language tag.

Note that only literals with the exact same language tag will be matched. This type does not implement language tag matching as specified by RFC4647.

Implementations

Source

impl<T> LanguageTagMatcher<T>
where T: Borrow<str>,

pub fn new(tag: LanguageTag<T>) -> LanguageTagMatcher<T>

Construct a new LanguageTagMatcher from a LanguageTag

pub fn unwrap(self) -> LanguageTag<T>

Destructs this LanguageTagMatcher

pub fn as_ref(&self) -> LanguageTag<&str>

Borrow the inner LanguageTag