pub struct Error { /* private fields */ }Expand description
Parsing error, capturing the position in the input where the error was encountered.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn position(&self) -> (usize, usize)
pub fn position(&self) -> (usize, usize)
Return the position in the input.
NB: lines and columns are numbered from 0.
Sourcepub fn in_context(&self, context: &str) -> String
pub fn in_context(&self, context: &str) -> String
Display this error with context.
This method numbers line and column starting from 1 instead of 0, as expected by text editors.