pub struct DatasetGraph<D, G>{ /* private fields */ }Expand description
I wrap a Dataset as a Graph
corresponding to a specific graph (default or named) of the wrapped dataset.
This graph is also mutable if the underlying dataset is.
NB: this type is design to be the return type of Dataset::graph and MutableDataset::graph_mut.
It is not designed to be usable “from scratch”.
Implementations