pub enum ResourceErrorKind<E>{
IriNotAbsolute(IriRef<Box<str>>),
LoaderError(LoaderError),
GraphError {
id: SimpleTerm<'static>,
error: E,
},
NoValueFor {
id: SimpleTerm<'static>,
predicate: SimpleTerm<'static>,
},
UnexpectedMultipleValueFor {
id: SimpleTerm<'static>,
predicate: SimpleTerm<'static>,
},
MissingType {
id: SimpleTerm<'static>,
typ: SimpleTerm<'static>,
},
UnexpectedKind {
id: SimpleTerm<'static>,
predicate: SimpleTerm<'static>,
found_kind: TermKind,
},
UnexpectedDatatype {
id: SimpleTerm<'static>,
predicate: SimpleTerm<'static>,
found_datatype: SimpleTerm<'static>,
},
UnexpectedValue {
id: SimpleTerm<'static>,
predicate: SimpleTerm<'static>,
found_value: SimpleTerm<'static>,
},
}Expand description
An error raised when creating a Resource
Variants
IriNotAbsolute(IriRef<Box<str>>)
The IRI is not absolute (an can therefore not be dereferenced)
LoaderError(LoaderError)
The resource could not be loaded
GraphError
The underlying graph raised an error
NoValueFor
A value was expected and not found for the given predicate on the given resource
Fields
id: SimpleTerm<'static>The identifier of the resource
predicate: SimpleTerm<'static>The predicate
UnexpectedMultipleValueFor
Multiple values were not expected and were found for the given predicate
Fields
id: SimpleTerm<'static>The identifier of the resource
predicate: SimpleTerm<'static>The predicate
MissingType
The node was expected to have given type
Fields
id: SimpleTerm<'static>The identifier of the resource
typ: SimpleTerm<'static>The expected type
UnexpectedKind
The term was expected to have a given kind
Fields
id: SimpleTerm<'static>The identifier of the resource
predicate: SimpleTerm<'static>The predicate
UnexpectedDatatype
The literal was expected to have a given datatype
Fields
id: SimpleTerm<'static>The identifier of the resource
predicate: SimpleTerm<'static>The predicate
found_datatype: SimpleTerm<'static>The datatype that was found
UnexpectedValue
The literal was expected to have a different value
Fields
id: SimpleTerm<'static>The identifier of the resource
predicate: SimpleTerm<'static>The predicate
found_value: SimpleTerm<'static>The datatype that was found